import { Fragment } from "react";
import { Container, Button, Stack } from "react-bootstrap";

import { useAppSelector } from "../hooks";
import { selectCategories } from "../store/cluesSlice";
import { socket } from "../socket";
import { debounce } from "../utils";

const CluesDisplay = () => {
  const categories = useAppSelector(selectCategories);

  const activateClue = debounce((name: string, value: number) => {
    socket.emit("activate-clue", { name, value });
  });

  return (
    <Container>
      <Stack gap={3} className="text-center">
        {categories.map(({ name }) => (
          <Fragment key={name}>
            <h2>{name}</h2>
            {[200, 400, 600, 800, 1000].map((value) => (
              <Button key={value} onClick={() => activateClue(name, value)}>
                {value}
              </Button>
            ))}
          </Fragment>
        ))}
      </Stack>
    </Container>
  );
};

export default CluesDisplay;
