import { createSlice, PayloadAction } from "@reduxjs/toolkit";
import type { RootState } from "./";

interface CluesState {
  activeClue: Clue | null;
  categories: Category[];
}

export interface Category {
  name: string;
  clues: Clue[];
}

export interface Clue {
  value: number;
  question: string;
  answer: string;
}

const initialState: CluesState = {
  activeClue: null,
  categories: [],
};

export const cluesSlice = createSlice({
  name: "clues",
  initialState,
  reducers: {
    setCategories: (
      state,
      { payload }: PayloadAction<Record<string, Clue[]>>
    ) => {
      state.categories = Object.entries(payload).map(([name, clues]) => ({
        name,
        clues,
      }));
    },
    setActiveClue: (state, { payload }: PayloadAction<Clue | null>) => {
      state.activeClue = payload;
    },
    clearActiveClue: (state) => {
      state.activeClue = null;
    },
  },
});

export const { setCategories, setActiveClue, clearActiveClue } =
  cluesSlice.actions;
export const selectCategories = (state: RootState) => state.clues.categories;
export const selectActiveClue = (state: RootState) => state.clues.activeClue;

export default cluesSlice.reducer;
